"""Pydantic models for database metadata and results."""

from .capabilities import DatabaseCapabilities
from .config import DatabaseConfig, SSHTunnelConfig
from .database import DatabaseInfo, SchemaInfo
from .query import ExplainPlan, QueryResult
from .statistics import ColumnStats, Distribution
from .table import ColumnInfo, ConstraintInfo, IndexInfo, TableInfo

__all__ = [
    "DatabaseCapabilities",
    "DatabaseConfig",
    "SSHTunnelConfig",
    "DatabaseInfo",
    "SchemaInfo",
    "TableInfo",
    "ColumnInfo",
    "IndexInfo",
    "ConstraintInfo",
    "QueryResult",
    "ExplainPlan",
    "ColumnStats",
    "Distribution",
]
